@@ -29,9 +29,9 @@
 #' @export
 read.community <- function(file, grids="grids", species="species", ...){
   d <- read.csv(file, stringsAsFactors = TRUE, ...)
-  M <- Matrix::sparseMatrix(as.integer(d[,grids]), as.integer(d[,species]),
+  M <- Matrix::sparseMatrix(as.integer(d[, grids]), as.integer(d[,species]),
                   x = rep(1L, nrow(d)),
-                  dimnames = list(levels(d[,"grids"]), levels(d[,"species"])))
+                  dimnames = list(levels(d[, grids]), levels(d[, species])))
   M
 }
 
